namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits<bool>::type Group::group_need_recalculate_get() const
{
   Eina_Bool __return_value =  ::efl_canvas_group_need_recalculate_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Group::group_need_recalculate_set( ::efl::eolian::in_traits<bool>::type value) const
{
    ::efl_canvas_group_need_recalculate_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(value));
}
inline ::efl::eolian::return_traits<void>::type Group::group_clip_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type clip) const
{
    ::efl_canvas_group_clip_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(clip));
}
inline ::efl::eolian::return_traits<void>::type Group::group_color_set( ::efl::eolian::in_traits<int>::type r,  ::efl::eolian::in_traits<int>::type g,  ::efl::eolian::in_traits<int>::type b,  ::efl::eolian::in_traits<int>::type a) const
{
    ::efl_canvas_group_color_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(r)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(g)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(b)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(a));
}
inline ::efl::eolian::return_traits<void>::type Group::group_no_render_set( ::efl::eolian::in_traits<bool>::type hide) const
{
    ::efl_canvas_group_no_render_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(hide));
}
inline ::efl::eolian::return_traits<void>::type Group::group_change() const
{
    ::efl_canvas_group_change(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_children_move( ::efl::eolian::in_traits<int>::type dx,  ::efl::eolian::in_traits<int>::type dy) const
{
    ::efl_canvas_group_children_move(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(dx)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(dy));
}
inline ::efl::eolian::return_traits<void>::type Group::group_calculate() const
{
    ::efl_canvas_group_calculate(this->_eo_ptr());
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Group::group_children_iterate() const
{
   Eina_Iterator * __return_value =  ::efl_canvas_group_children_iterate(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Group::group_show() const
{
    ::efl_canvas_group_show(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_move( ::efl::eolian::in_traits<Evas_Coord>::type x,  ::efl::eolian::in_traits<Evas_Coord>::type y) const
{
    ::efl_canvas_group_move(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(x)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Group::group_hide() const
{
    ::efl_canvas_group_hide(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_add() const
{
    ::efl_canvas_group_add(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_member_add( ::efl::eolian::in_traits< ::efl::canvas::Object>::type sub_obj) const
{
    ::efl_canvas_group_member_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(sub_obj));
}
inline ::efl::eolian::return_traits<void>::type Group::group_resize( ::efl::eolian::in_traits<Evas_Coord>::type w,  ::efl::eolian::in_traits<Evas_Coord>::type h) const
{
    ::efl_canvas_group_resize(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(w)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(h));
}
inline ::efl::eolian::return_traits<void>::type Group::group_clip_unset() const
{
    ::efl_canvas_group_clip_unset(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_member_del( ::efl::eolian::in_traits< ::efl::canvas::Object>::type sub_obj) const
{
    ::efl_canvas_group_member_del(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(sub_obj));
}
inline ::efl::eolian::return_traits<void>::type Group::group_del() const
{
    ::efl_canvas_group_del(this->_eo_ptr());
}
} } 
namespace eo_cxx {
namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits<bool>::type Group::group_need_recalculate_get() const
{
   Eina_Bool __return_value =  ::efl_canvas_group_need_recalculate_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Group::group_need_recalculate_set( ::efl::eolian::in_traits<bool>::type value) const
{
    ::efl_canvas_group_need_recalculate_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(value));
}
inline ::efl::eolian::return_traits<void>::type Group::group_clip_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type clip) const
{
    ::efl_canvas_group_clip_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(clip));
}
inline ::efl::eolian::return_traits<void>::type Group::group_color_set( ::efl::eolian::in_traits<int>::type r,  ::efl::eolian::in_traits<int>::type g,  ::efl::eolian::in_traits<int>::type b,  ::efl::eolian::in_traits<int>::type a) const
{
    ::efl_canvas_group_color_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(r)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(g)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(b)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(a));
}
inline ::efl::eolian::return_traits<void>::type Group::group_no_render_set( ::efl::eolian::in_traits<bool>::type hide) const
{
    ::efl_canvas_group_no_render_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(hide));
}
inline ::efl::eolian::return_traits<void>::type Group::group_change() const
{
    ::efl_canvas_group_change(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_children_move( ::efl::eolian::in_traits<int>::type dx,  ::efl::eolian::in_traits<int>::type dy) const
{
    ::efl_canvas_group_children_move(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(dx)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(dy));
}
inline ::efl::eolian::return_traits<void>::type Group::group_calculate() const
{
    ::efl_canvas_group_calculate(this->_eo_ptr());
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Group::group_children_iterate() const
{
   Eina_Iterator * __return_value =  ::efl_canvas_group_children_iterate(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Group::group_show() const
{
    ::efl_canvas_group_show(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_move( ::efl::eolian::in_traits<Evas_Coord>::type x,  ::efl::eolian::in_traits<Evas_Coord>::type y) const
{
    ::efl_canvas_group_move(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(x)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(y));
}
inline ::efl::eolian::return_traits<void>::type Group::group_hide() const
{
    ::efl_canvas_group_hide(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_add() const
{
    ::efl_canvas_group_add(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_member_add( ::efl::eolian::in_traits< ::efl::canvas::Object>::type sub_obj) const
{
    ::efl_canvas_group_member_add(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(sub_obj));
}
inline ::efl::eolian::return_traits<void>::type Group::group_resize( ::efl::eolian::in_traits<Evas_Coord>::type w,  ::efl::eolian::in_traits<Evas_Coord>::type h) const
{
    ::efl_canvas_group_resize(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(w)
      ,  ::efl::eolian::convert_to_c<Evas_Coord,  ::efl::eolian::in_traits<Evas_Coord>::type>(h));
}
inline ::efl::eolian::return_traits<void>::type Group::group_clip_unset() const
{
    ::efl_canvas_group_clip_unset(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Group::group_member_del( ::efl::eolian::in_traits< ::efl::canvas::Object>::type sub_obj) const
{
    ::efl_canvas_group_member_del(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(sub_obj));
}
inline ::efl::eolian::return_traits<void>::type Group::group_del() const
{
    ::efl_canvas_group_del(this->_eo_ptr());
}
inline efl::canvas::Group::operator ::efl::canvas::Group() const { return *static_cast< ::efl::canvas::Group const*>(static_cast<void const*>(this)); }
inline efl::canvas::Group::operator ::efl::canvas::Group&() { return *static_cast< ::efl::canvas::Group*>(static_cast<void*>(this)); }
inline efl::canvas::Group::operator ::efl::canvas::Group const&() const { return *static_cast< ::efl::canvas::Group const*>(static_cast<void const*>(this)); }
} } }

